@@ -9,7 +9,8 @@
 ;; Maintainer: USAMI Kenta <tadsan@zonu.me>
 ;; URL: https://github.com/emacs-php/php-mode
 ;; Keywords: languages php
-;; Version: 1.26.1
+;; Package-Version: 1.27.0
+;; Package-Revision: c3fa4e020cdb
 ;; Package-Requires: ((emacs "27.1"))
 ;; License: GPL-3.0-or-later
 
@@ -627,7 +628,8 @@ but only if the setting is enabled."
    ((assq 'defun-block-intro c-syntactic-context) nil)
    ((assq 'defun-close c-syntactic-context) nil)
    ((assq 'statement-cont c-syntactic-context) nil)
-   ((save-excursion
+   (t
+    (save-excursion
       (beginning-of-line)
       (let ((beginning-of-langelem (cdr langelem))
             (beginning-of-current-line (point))
@@ -650,10 +652,8 @@ but only if the setting is enabled."
               (skip-chars-backward " 	\r\n")
               (backward-char 1))
             (and (not (eq (point) beginning-of-current-line))
-                 (not (php-in-string-or-comment-p))
                  (not (looking-at-p ","))
-                 (save-excursion
-                   (backward-char) (not (looking-at-p ",")))))
+                 (not (php-in-string-or-comment-p))))
           '+)
          (t nil)))))))
 
