@@ -5,7 +5,6 @@
 
 ;; Author: USAMI Kenta <tadsan@zonu.me>
 ;; Created: 5 Dec 2018
-;; Version: 1.26.1
 ;; Keywords: languages, php
 ;; Homepage: https://github.com/emacs-php/php-mode
 ;; License: GPL-3.0-or-later
@@ -49,24 +48,12 @@
   :link '(url-link :tag "Official Site" "https://github.com/emacs-php/php-mode")
   :link '(url-link :tag "PHP Mode Wiki" "https://github.com/emacs-php/php-mode/wiki"))
 
-(defcustom php-executable (or (executable-find "php") "php")
+(defcustom php-executable (or (executable-find "php") "/usr/bin/php")
   "The location of the PHP executable."
   :group 'php
   :tag "PHP Executable"
   :type 'string)
 
-(defcustom php-phpdbg-executable (list "phpdbg")
-  "The location of the PHPDBG executable."
-  :group 'php
-  :tag "PHP PHPDBG Executable"
-  :type '(repeat string))
-
-(defcustom php-php-parse-executabe nil
-  "The location of the php-parse executable."
-  :group 'php
-  :tag "PHP php-parse Executable"
-  :type '(repeat string))
-
 (defcustom php-site-url "https://www.php.net/"
   "Default PHP.net site URL.
 
@@ -337,18 +324,12 @@ can be used to match against definitions for that classlike."
      ;; First see if 'abstract' or 'final' appear, although really these
      ;; are not valid for all values of `type' that the function
      ;; accepts.
-     (eval-when-compile
-       (rx line-start
-           (* (syntax whitespace))
-           (? (or "abstract" "final" "readonly")
-              (+ (syntax whitespace)))))
+     "^\\s-*\\(?:\\(?:abstract\\|final\\)\\s-+\\)?"
      ;; The classlike type
      type
      ;; Its name, which is the first captured group in the regexp.  We
      ;; allow backslashes in the name to handle namespaces, but again
      ;; this is not necessarily correct for all values of `type'.
-     ;; (rx (+ (syntax whitespace))
-     ;;     (group (+ (or (syntax word) "\\" (syntax symbol)))))
      "\\s-+\\(\\(?:\\sw\\|\\\\\\|\\s_\\)+\\)")))
 
 (defconst php-imenu-generic-expression-default
@@ -483,7 +464,7 @@ can be used to match against definitions for that classlike."
 
 (defconst php--re-classlike-pattern
   (eval-when-compile
-    (php-create-regexp-for-classlike (regexp-opt '("class" "interface" "trait" "enum")))))
+    (php-create-regexp-for-classlike (regexp-opt '("class" "interface" "trait")))))
 
 (defvar php--analysis-syntax-table
   (eval-when-compile
@@ -682,15 +663,17 @@ Currently there are `php-mode' and `php-ts-mode'."
 (defun php-current-class ()
   "Insert current class name if cursor in class context."
   (interactive)
-  (when-let* ((matched (php-get-current-element php--re-classlike-pattern)))
-    (insert (concat matched php-class-suffix-when-insert))))
+  (let ((matched (php-get-current-element php--re-classlike-pattern)))
+    (when matched
+      (insert (concat matched php-class-suffix-when-insert)))))
 
 ;;;###autoload
 (defun php-current-namespace ()
   "Insert current namespace if cursor in namespace context."
   (interactive)
-  (when-let* ((matched (php-get-current-element php--re-namespace-pattern)))
-    (insert (concat matched php-namespace-suffix-when-insert))))
+  (let ((matched (php-get-current-element php--re-namespace-pattern)))
+    (when matched
+      (insert (concat matched php-namespace-suffix-when-insert)))))
 
 ;;;###autoload
 (defun php-copyit-fqsen ()
@@ -816,29 +799,5 @@ When `DOCUMENT-ROOT' is NIL, the document root is obtained from `ROUTER-OR-DIR'.
                       #'file-exists-p))))
   (find-file file))
 
-
-(defun php-phpdbg-disassemble-file (file)
-  "Read PHP FILE and print opcodes."
-  (interactive (list (if (or buffer-file-name (zerop (prefix-numeric-value current-prefix-arg)))
-                         buffer-file-name
-                       (expand-file-name
-                        (read-file-name "Select PHP file: " default-directory buffer-file-name)))))
-  (let ((args `(,@php-phpdbg-executable "-dopcache.enable_cli=1" "-p*" ,file)))
-    (compile (mapconcat #'shell-quote-argument args " "))))
-
-(defun php-parse-file (file)
-  "Parse PHP FILE and print node tree."
-  (interactive (list (if (or buffer-file-name (zerop (prefix-numeric-value current-prefix-arg)))
-                         buffer-file-name
-                       (expand-file-name
-                        (read-file-name "Select PHP file: " default-directory buffer-file-name)))))
-  (let* ((project-dir (php-project-get-root-dir))
-         (executable (or php-php-parse-executabe
-                         (file-executable-p (expand-file-name "vendor/bin/php-parse" project-dir))
-                         (executable-find "php-parse")
-                         (user-error "`php-parse' command not found")))
-         (args `(,@(if (listp executable) executable (list executable)) ,file)))
-    (compile (mapconcat #'shell-quote-argument args " "))))
-
 (provide 'php)
 ;;; php.el ends here
